pub struct Response<T = Value, E = Value> {
pub result: Result<T, Error<E>>,
pub id: Id,
}Expand description
A JSON-RPC 2.0 response object.
Note that the "jsonrpc": "2.0" member is transparently checked during
deserialization, and added during serialization.
Fields
result: Result<T, Error<E>>“result”:
This member is REQUIRED on success. This member MUST NOT exist if there was an error invoking the method. The value of this member is determined by the method invoked on the Server.
“error”:
This member is REQUIRED on error. This member MUST NOT exist if there was no error triggered during invocation.
id: IdThis member is REQUIRED. It MUST be the same as the value of the id member in the Request Object. If there was an error in detecting the id in the Request object (e.g. Parse error/Invalid Request), it MUST be Null.